'****************************************************************************************************
'*                                                                                                  
'* DriveIt v1.0 (c) albasoft 09.04.2003
'* Administrator utility to collect drive space and more data
'*                                                                                                  
'****************************************************************************************************
'
'  ARRAY STRUCTURES:
'
'  aDrives --|-0- Root folder            aDriveData --|- Drive --|-0- Date
'            |-1- Total size                                     |-1- Free space
'
'
'  aUsers  --|-0- User name              aUserData  --|- User  --|-0- Date
'          --|-1- User path                                      |-1- User dir size
'
'****************************************************************************************************


Option Explicit
'On Error Resume Next


'****************************************************************************************************
'Directories if local must be given with full name
CONST REPORT_DIR      = "\\..."
CONST LOG_DIR         = "\\..."

CONST DRIVE_EXTENSION = ".dtf"
CONST USER_EXTENSION  = ".utf"
CONST USER_COUNT      = 500
CONST MAIL_RECIP      = "mail@admin"


' Strings for the mail message
DIM sHeader, sDriveData, sMail

' History variables
DIM aDrives(),aDriveData(), iDriveToday, iDriveYesterday, iDriveLastWeek, iDriveLastMonth
DIM aUsers(), aUserData(),  iUserToday,  iUserYesterday,  iUserLastWeek,  iUserLastMonth

' General Variables
DIM oFSO, sComputerName, sDataDir, sReportFile, sTxtReportFile



'***************************************************************************************************
'SCRIPT START
'***************************************************************************************************
  Redim aDrives(0)
  Redim aDriveData(0)
  Redim aUsers(0)
  Redim aUserData(0)

  Wscript.Echo
  WScript.Echo "   DriveIt V1.0 (c) 2003 albasoft"
  WScript.Echo "   SysAdmin utility"
  Wscript.Echo
  Wscript.Echo "   " & Date & " - " & Time
  Wscript.Echo

' First check the log file if DriveIt has already runed today
  If Not HasRunned Then
    Call GetArguments(Wscript.Arguments)
'   Check if data folder for the current exists
    CheckIfDataFolder
'   Now test the computer if the drives can be accessed and run GetDriveData for each valid drive
    TestDrives
'   Get the drive history for all drives and place it into arrays
	GetDriveHistory
'   Get the user data and write it to data file
	FindUserFolders
'   Get the user history for all users and place it into arrays
    GetUserHistory
'   Now write the daily report
	WriteReport
	WriteTextReport
'	Finally place an email to the admin
    SendMail
  End If
  Wscript.Echo "   Shutting down."  	  
'***************************************************************************************************
'SCRIPT END
'***************************************************************************************************



'***************************************************************************************************
' FUNCTION HasRunned
' Check the log file if DriveIt has already runed today
'***************************************************************************************************
FUNCTION HasRunned
    DIM oFile, sBuf1, sBuf2
	Set oFSO = CreateObject("Scripting.FileSystemObject")
    Set oFile = oFSO.OpenTextFile(LOG_DIR & "\" & "driveit.log", 1, TRUE, 0)
    sBuf1 = Date
    Do While Not oFile.atEndOfStream
      sBuf2 = oFile.ReadLine
	  If Left(sBuf1,10) = Left(sBuf2,10) Then 
        PutMess "Data has already been written today.", FALSE
		Wscript.Echo
	    HasRunned = TRUE
   	    oFile.Close
		Set oFile = nothing
	    Set oFSO  = nothing
	    Exit Function
      End If
    Loop
	HasRunned = FALSE  
	oFile.Close
    Set oFile = nothing
    Set oFSO  = nothing
END FUNCTION



'***************************************************************************************************
' SUB GetArguments
' Get all the neccessary user input
'***************************************************************************************************
SUB GetArguments(oArgs)
	DIM iCount
'   Parse the different arguments
	For iCount=0 To oArgs.Count - 1
	  Select Case UCase(Split(WScript.Arguments(iCount), "=")(0))
'		Case "TARGET"    sTarget      = Split(WScript.Arguments(iCount), "=")(1)
	  End Select
    Next
'   Check if all is ok	
'	If sTarget = "" Then
'	  Wscript.echo "  * You did not specify a target drive!"
'     Wscript.echo
'	  Wscript.echo "  Terminating."
'     ShowUsage
'    End If 
END SUB



'***************************************************************************************************
' SUB CheckIfDataFolder
' Create the yearly data folder if not present
'***************************************************************************************************
SUB CheckIfDataFolder
    DIM sBuf
    Set oFSO = CreateObject("Scripting.FileSystemObject")
    sBuf = Date
	If Not oFSO.FolderExists(Right(sBuf,4)) Then
      oFSO.CreateFolder (Right(sBuf,4))
    End If 
	sDataDir = oFSO.GetFolder(".") & "\" & Right(sBuf,4)
    Set oFSO = nothing
END SUB



'***************************************************************************************************
' SUB TestDrives
' First test the computer if the fixed drives can be accessed
'***************************************************************************************************
SUB TestDrives
    DIM oDrives, oDrive
	Set oFSO = CreateObject("Scripting.FileSystemObject")
    Set oDrives = oFSO.Drives
	PutMess "Scanning Computer for physical drives...", TRUE
	Wscript.Echo
	For Each oDrive in oDrives
      If oDrive.DriveType = 2 Then
  	    GetDriveData(oDrive.RootFolder)
      End If
    Next
	If Err <> 0 Then PutMess "Could not get drive listing.", FALSE
	Set oDrives = nothing
	Set oFSO    = nothing
END SUB



'***************************************************************************************************
' SUB GetDriveData
' Get all available info on one drive
'***************************************************************************************************
SUB GetDriveData(sInput)
    DIM WshNetwork, oDrive, oFile, iBuf
	DIM sDomain, sBuf1, sBuf2

   'First create the objects 	
	Set oFSO = CreateObject("Scripting.FileSystemObject")
    Set oDrive = oFSO.GetDrive(oFSO.GetDriveName(sInput))
    Set WshNetwork = WScript.CreateObject("WScript.Network")

   'If all is ok proceed
	If Err <> 0 Then 
	  PutMess "Cannot create FSO or Network objects", FALSE
    Else	

	 'Let the user know what is going on
  	  sComputerName  = WshNetwork.ComputerName
      sDomain        = WshNetwork.UserDomain
	  PutMess "Getting drive data " & UCase(sInput) & " on " & sDomain & "/" & sComputerName & " ..." , TRUE

	 'Let's see if the drive today has been checked 
	  If oDrive.SerialNumber < 0 Then
	    iBuf = oDrive.SerialNumber * - 1
      Else
	    iBuf = oDrive.SerialNumber
      End If
  
	 'The drive is new today!
	  sDriveData = "       Total Space MB: " & FormatNumber(oDrive.TotalSize / 1024, 0) & vbCrLf
	  sDriveData = sDriveData & "       User Space  MB: " & FormatNumber(oDrive.FreeSpace / 1024, 0) & vbCrLf  
	  sDriveData = SDriveData & "       User Ratio    : " & FormatNumber((oDrive.FreeSpace * 100) / oDrive.TotalSize,1) & " %"
	  Wscript.echo sDriveData
      
	  Set oFSO = CreateObject("Scripting.FileSystemObject")
	  Set oFile = oFSO.OpenTextFile(sDataDir & "\" & iBuf & ".dtf", 8, TRUE, 0)
      oFile.WriteLine(oDrive.RootFolder)
	  oFile.WriteLine(oDrive.TotalSize) 
      oFile.WriteLine(Date)
	  oFile.WriteLine(oDrive.FreeSpace)
      oFile.Close

	  Set oFile      = nothing
	  Set oDrive     = nothing 
	  Set oFSO       = nothing
	  Set WshNetWork = nothing
      PutMess "Drive data " & sInput & " collected on " & sDomain & "/" & sComputerName & " ...", TRUE
	  Wscript.Echo
    End If
END SUB



'***************************************************************************************************
' SUB GetDriveHistory
' Get the drive history for all drives and place it into arrays
'***************************************************************************************************
SUB GetDriveHistory
    DIM oFSO, oFolder, oFile, sBuf, iFile, iDate, iFileCount
    Set oFSO = CreateObject("Scripting.FileSystemObject")
    Set oFolder  = oFSO.GetFolder(sDataDir)

   'First get the number of files
	For Each oFile In oFolder.Files
      sBuf = Right(oFile.Name, 4)
	  If UCase(sBuf) = UCase(".dtf") Then
	    iFileCount = iFileCount + 1
       End If
    Next 
   'Resize the arrays
	Redim aDrives(iFileCount-1,1)
    Redim aDriveData(iFileCount-1,365,1)

	iFile = 0
	For Each oFile In oFolder.Files
      sBuf = Right(oFile.Name, 4)
	  If UCase(sBuf) = UCase(".dtf") Then
	   'Read the first block
		iDate = 0
		Set oFile = oFSO.OpenTextFile(sDataDir & "\" & oFile.Name, 1, TRUE, 0)
        aDrives(iFile,0) = oFile.ReadLine
		aDrives(iFile,1) = ofile.ReadLine
        aDriveData(iFile,iDate,0) = oFile.ReadLine
        aDriveData(iFile,iDate,1) = oFile.ReadLine
       'Now read the rest of data
		Do While Not oFile.atEndOfStream
          oFile.ReadLine ' Jump the name
		  oFile.ReadLine ' Jump the total space
          iDate = iDate + 1
          aDriveData(iFile,iDate,0) = oFile.ReadLine
          aDriveData(iFile,iDate,1) = oFile.ReadLine
        Loop
		oFile.Close
      End If
	  iFile = iFile + 1 
    Next
	Set oFile   = nothing
	Set oFolder = nothing
	Set oFSO    = nothing
END SUB



'***************************************************************************************************
' SUB FindUserFolders
' Search the drives for user folders
'***************************************************************************************************
SUB FindUserFolders
    DIM oFolder, oDrives, oDrive, oSubFolder, iCount, oFile
   	Set oFSO = CreateObject("Scripting.FileSystemObject")
    Set oDrives = oFSO.Drives
	Redim aUsers(USER_COUNT,2)
	iCount = 0
	PutMess "Scanning Computer for user folders...", TRUE
	Wscript.Echo
	For Each oDrive in oDrives
      If oDrive.DriveType = 2 Then
  		Set oFSO = CreateObject("Scripting.FileSystemObject")
		If oFSO.FolderExists(oDrive.RootFolder & "users") Then
		  PutMess "Found user folders on " &  oDrive.RootFolder, TRUE
		  PutMess "Now scanning. Stay tuned, this may take a while...", TRUE
          Set oFSO = CreateObject("Scripting.FileSystemObject")
		  Set oFolder  = oFSO.GetFolder(oDrive.RootFolder & "users")
          For Each oSubFolder In oFolder.SubFolders
			  If not oSubFolder.Attributes and 4 Then
  		        If oSubFolder.Name <> "publicviro" Then 
                  Set oFile = oFSO.OpenTextFile(sDataDir & "\" & oSubFolder.Name & USER_EXTENSION, 8, TRUE, 0)
                  oFile.WriteLine(oSubFolder.Name)
				  oFile.WriteLine(oSubFolder.Path)
                  oFile.WriteLine(date)
				  oFile.WriteLine(oSubFolder.Size)
				  wscript.echo "     - " & oSubFolder.path & " : "  & oSubFolder.Size    
				  oFile.Close
				  Set oFile = nothing
               End If  
              End If
          Next
        End If
	  End If
	Next  
	Set oFolder = nothing
	Set oDrives = nothing
	Set oFSO    = nothing
END SUB



'***************************************************************************************************
' SUB GetUserHistory
' Get the user history for all users and place it into arrays
'***************************************************************************************************
SUB GetUserHistory
    DIM oFolder, oFile, sBuf, iFile, iDate, iFileCount
    Set oFSO = CreateObject("Scripting.FileSystemObject")
    Set oFolder  = oFSO.GetFolder(sDataDir)

   'First get the number of files
	iFileCount = 0
	For Each oFile In oFolder.Files
      sBuf = Right(oFile.Name, 4)
	  If UCase(sBuf) = UCase(USER_EXTENSION) Then
	    iFileCount = iFileCount + 1
       End If
    Next 
   'Resize the arrays
	Redim aUsers(iFileCount-1,1)
	Redim aUserData(iFileCount-1,365,1)


	iFile = 0
	For Each oFile In oFolder.Files
      sBuf = Right(oFile.Name, 4)
	  If UCase(sBuf) = UCase(USER_EXTENSION) Then
	   'Read the first block
		iDate = 0
		Set oFile = oFSO.OpenTextFile(sDataDir & "\" & oFile.Name, 1, TRUE, 0)
        aUsers(iFile,0) = oFile.ReadLine
		aUsers(iFile,1) = ofile.ReadLine
        aUserData(iFile,iDate,0) = oFile.ReadLine
        aUserData(iFile,iDate,1) = oFile.ReadLine
       'Now read the rest of data
		Do While Not oFile.atEndOfStream
		  oFile.ReadLine ' Jump the name
		  oFile.ReadLine ' Jump the path
          iDate = iDate + 1
          aUserData(iFile,iDate,0) = oFile.ReadLine  'Get the date
          aUserData(iFile,iDate,1) = oFile.ReadLine  'Get the size
        Loop
		oFile.Close
  	    iFile = iFile + 1 
	  End If
    Next
	Set oFile   = nothing
	Set oFolder = nothing
	Set oFSO    = nothing
END SUB



'***************************************************************************************************
' SUB WriteReport
' Writes a html file with all data
'***************************************************************************************************
SUB WriteReport
    DIM oFSO, oFile, sName, iCount, sUser
	DIM sDate, sYear, sMonth, sDay
    sDate    = Date
	sYear    = Right(sDate, 4)
	sMonth   = Left(sDate,5)
	sMonth   = Right(sMonth,2)
	sDay     = Left(sDate,2)
    
    Set oFSO = CreateObject("Scripting.FileSystemObject")
	Set oFile = oFSO.OpenTextFile(REPORT_DIR & "\" & sDay & "_" & sMonth & "_" & sYear & ".htm", 2, TRUE, 0)
	sReportFile = sDay & "_" & sMonth & "_" & sYear & ".htm"
    
    oFile.WriteLine("<!DOCTYPE html PUBLIC" & Chr(34) & "-//W3C//DTD HTML 4.01 Transitional//EN" & Chr(34) & ">") &_
    oFile.WriteLine("<HEAD>")
    oFile.WriteLine("<TITLE>")
	oFile.WriteLine("DriveIt report")
    oFile.WriteLine("</TITLE>")
    oFile.WriteLine("</HEAD>")
	oFile.WriteLine("<HTML>")
	oFile.WriteLine("<BODY bgcolor=" & Chr(34) & "#EEEEEE" & Chr(34) & ">")
	oFile.WriteLine("<PRE>")
	oFile.WriteLine("<FONT FACE=" & Chr(34) & "MS SANS SERIF"& Chr(34) & ">")
	oFile.WriteLine("<FONT SIZE=5>")
	oFile.WriteLine("<B>DriveIt <SMALL>&copy;</SMALL> Global Report on " & sComputerName & " </B>")
	oFile.WriteLine("<FONT SIZE=2>")
	oFile.WriteLine("<B>" & Date & "</B>")
	oFile.WriteLine("<A HREF=" & Chr(34) & "driveit.log" & Chr(34) & ">LOGFILE</A>")
	oFile.WriteLine("<BR>")
	oFile.WriteLine("<BR>")
	oFile.WriteLine("<B> <U>PART 1 : Today's server statistics</B></U>")
	oFile.WriteLine
	iCount = 0
    oFile.WriteLine("<TABLE>")
	For Each sName In aDrives
	  If iCount <= UBound(aDrives,1) Then
	    If aDrives(iCount,0) <> "" and aDrives(iCount,0) <> "0" and aDrives(iCount,0) <> " " and aDrives(iCount,1) <> 0 Then
          CalcDriveHistory(iCount)
	      oFile.WriteLine("<TR><TD> Drive name   </TD> <TD> : </TD> <TD>" & sName & "</TD></TR>")
	      oFile.WriteLine("<TR><TD> Total space  </TD> <TD> : </TD> <TD>" & FormatNumber((((aDrives(iCount,1)) / 1024) / 1024) / 1024 ,3) & " GB</TD>")
          oFile.WriteLine("<TD width=50></TD>")
		  If iDriveYesterday = -1 Then
  		    oFile.WriteLine("<TD> Space growth yesterday</TD> <TD> : </TD> <TD>" & "not applicable" & "</TD></TR>")
          Else
		  oFile.WriteLine("<TD> Space growth yesterday</TD> <TD> : </TD> <TD>" & FormatNumber((((iDriveToday - iDriveYesterday) / 1024) / 1024) / 1024 ,3) & " GB</TD></TR>")
          End If
		  oFile.WriteLine("<TR><TD> Free space   </TD> <TD> : </TD> <TD>" & FormatNumber((((iDriveToday) / 1024) / 1024) / 1024 ,3) & " GB</TD>")
          oFile.WriteLine("<TD width=50></TD>")
		  If iDriveLastWeek = -1 Then
  		    oFile.WriteLine("<TD> Space growth last week</TD> <TD> : </TD> <TD>" & "not applicable" & "</TD></TR>")
          Else
            oFile.WriteLine("<TD> Space growth last week</TD> <TD> : </TD> <TD>" & FormatNumber((((iDriveToday - iDriveLastWeek) / 1024) / 1024) / 1024 ,3) & " GB</TD></TR>")
          End If
		  oFile.WriteLine("<TR><TD> Free ratio   </TD> <TD> : </TD> <TD>" & FormatNumber((iDriveToday * 100) / aDrives(iCount,1),1) & " %")
          oFile.WriteLine("<TD width=50></TD>")
		  If iDriveLastMonth = -1 Then
  		    oFile.WriteLine("<TD> Space growth last month</TD> <TD> : </TD> <TD>" & "not applicable" & "</TD></TR>")
          Else
            oFile.WriteLine("<TD> Space growth last month</TD> <TD> : </TD> <TD>" & FormatNumber((((iDriveToday - iDriveLastMonth) / 1024) / 1024) / 1024 ,3) & " GB</TD></TR>")
          End If
		  iCount = iCount + 1
        End If
        oFile.WriteLine("<TR><TD><HR></TD><TD></TD><TD><HR></TD><TD></TD><TD><HR></TD><TD></TD><TD><HR></TD></TR>")
      End If
    Next
    oFile.WriteLine("</TABLE>")
    oFile.WriteLine


    oFile.WriteLine("<B> <U>PART 2 : Today's User statistics</B></U>")
    oFile.WriteLine
	iCount = 0
    oFile.WriteLine("<TABLE>")
	For Each sName In aUsers
	  If sName <> "" and sName <> "0" and sName <> " " Then
        If iCount <= UBound(aUsers,1) Then
		  CalcUserHistory(iCount)

		  oFile.WriteLine("<TR><TD> User name              </TD> <TD> : </TD> <TD>" & aUsers(iCount,0) & "</TD>")
'         Change to yesterday
          oFile.WriteLine("<TD width=30></TD>")
		  If iUserYesterday = -1 Then
  		    oFile.WriteLine("<TD> Space growth yesterday</TD> <TD> : </TD> <TD>" & "not applicable" & "</TD></TR>")
          Else
		    oFile.WriteLine("<TD> Space growth yesterday</TD> <TD> : </TD> <TD>" & FormatNumber(((iUserYesterday - iUserToday) / 1024) / 1024 , 3) & " MB</TD></TR>")
          End If

		  oFile.WriteLine("<TR><TD> User path   </TD> <TD> : </TD> <TD>" & aUsers(iCount,1) & "</TD>")
          oFile.WriteLine("<TD width=30></TD>")
'         Change to last week
		  If iUserLastWeek = -1 Then
  		    oFile.WriteLine("<TD> Space growth last week</TD> <TD> : </TD> <TD>" & "not applicable" & "</TD></TR>")
          Else
            oFile.WriteLine("<TD> Space growth last week</TD> <TD> : </TD> <TD>" & FormatNumber(((iUserLastWeek - iUserToday) / 1024) / 1024 , 3) & " MB</TD></TR>")
          End If

		  oFile.WriteLine("<TR><TD> Disk usage  </TD> <TD> : </TD> <TD>" & FormatNumber((iUserToday / 1024) / 1024 , 3) & " MB</TD>")
          oFile.WriteLine("<TD width=30></TD>")
'         Change to last month
		  If iUserLastMonth = -1 Then
  		    oFile.WriteLine("<TD> Space growth last month</TD> <TD> : </TD> <TD>" & "not applicable" & "</TD></TR>")
          Else
            oFile.WriteLine("<TD> Space growth last month</TD> <TD> : </TD> <TD>" & FormatNumber(((iUserLastMonth - iUserToday) / 1024) / 1024 , 3) & " MB</TD></TR>")
          End If

          oFile.WriteLine("<TR><TD><HR></TD><TD></TD><TD><HR></TD><TD></TD><TD><HR></TD><TD></TD><TD><HR></TD></TR>")
        End If
  	    iCount = iCount + 1
      End If
    Next
    oFile.WriteLine("</TABLE>")
    oFile.WriteLine("</PRE>")
    oFile.WriteLine("</BODY>")
	oFile.WriteLine("</HTML>")
    oFile.Close
	Set oFile = nothing
	Set oFSO  = nothing
END SUB



'***************************************************************************************************
' SUB SendMail
' Place an email to the admin
'***************************************************************************************************
SUB SendMail
    DIM oJMail, Msg
	Wscript.echo
	Wscript.echo "   * Trying to send mail..."  	  
	Set oJMail = CreateOBject( "JMail.Message" )
	oJMail.silent  = true
    oJMail.Logging = true
	oJMail.From = "DriveIt@med.uni-tuebingen.de"
    oJMail.FromName = "DriveIt"
	oJMail.AddRecipient MAIL_RECIP
	oJMail.AddRecipient "hsschulz@med.uni-tuebingen.de"
	oJMail.Subject = "DriveIt report"
    oJMail.ContentType = "text/html"
    oJMail.Body = "<!DOCTYPE html PUBLIC" & Chr(34) & "-//W3C//DTD HTML 4.01 Transitional//EN" & Chr(34) & ">" &_
                  "<html>" &_
                  "<head>" &_
                  "<meta http-equiv=" & Chr(34) & "Content-Type" & Chr(34) & "content=" & Chr(34) & "text/html;charset=ISO-8859-1" & Chr(34) & ">" &_
                  "<title></title>" &_
                  "</head>" &_
                  "<body>" &_
                  "<FONT FACE=" & Chr(34) & "MS SANS SERIF"& Chr(34) & ">" &_
                  "<FONT SIZE=2>" &_
				  "<PRE>" &_
				  "Hello administrator, <BR><BR>" &_
				  "it is " & date & " and the daily DriveIt report is ready. <BR>" &_
				  "You can find it " &_
				  "<a href=" & Chr(34) & "http://virwts02/driveit/" & sReportFile & Chr(34) & ">" & "HERE." & "</a>" &_
				  "</PRE>" &_
                  "</body>" &_
                  "</html>"	
   
	If Not oJMail.Send("smtp.zit.med.uni-tuebingen.de") then
      PutMess "Check mail server and recipient.", FALSE
	Else
      PutMess "Mail sent.", TRUE
    End If
	Set oJMail = nothing
END SUB



'***************************************************************************************************
' SUB PutMess
' Places a message in the job log file and gives echo
'***************************************************************************************************
SUB PutMess(Msg, isOK)
	DIM oFile
	If isOK then
	  Wscript.Echo "   * " & Msg
    Else
	  Wscript.Echo "   ! " & Msg
    End If
    Set oFSO  = CreateObject("Scripting.FileSystemObject")
	Set oFile = oFSO.OpenTextFile(LOG_DIR & "\" & "driveit.log", 8, TRUE, 0)
	oFile.WriteLine (date & " - " & time & " : "& Msg)
    oFile.Close
    If Err <> 0 Then PutMess "Error writing message..." 
    Set oFile = nothing
    Set oFSO  = Nothing
END SUB



'***************************************************************************************************
' SUB CalcDriveHistory
' Calculate the drive history
'***************************************************************************************************
SUB CalcDriveHistory(iCount)
    DIM sBuf, iDate
	iDate          = 0
	iDriveToday     = 0
	iDriveYesterday = -1
	iDriveLastWeek  = -1
	iDriveLastMonth = -1
    Do While aDriveData(iCount,iDate,1) <> 0
      If aDriveData(iCount,iDate,1) <> 0 Then
		iDriveToday = aDriveData(iCount,iDate,1)
		iDate = iDate + 1
      End If
	Loop
	If iDate > 1 Then
      iDriveYesterday = aDriveData(iCount,iDate - 2,1)
    End If
	If iDate > 6 Then
      iDriveLastWeek = aDriveData(iCount,iDate - 7,1)
    End If
	If iDate > 29 Then
      iDriveLastMonth = aDriveData(iCount,iDate - 30,1)
    End If
    If Err <> 0 Then PutMess "Error calculating drive history" 
END SUB



'***************************************************************************************************
' SUB CalcUserHistory
' Calculate the user history
'***************************************************************************************************
SUB CalcUserHistory(iCount)
    DIM sBuf, iDate
	iDate          = 0
	iUserToday     = 0
	iUserYesterday = -1
	iUserLastWeek  = -1
	iUserLastMonth = -1
    Do While aUserData(iCount,iDate,1) <> 0
      If aUserData(iCount,iDate,1) <> 0 Then
		iUserToday = aUserData(iCount,iDate,1)
		iDate = iDate + 1
      End If
	Loop
	If iDate > 1 Then
      iUserYesterday = aUserData(iCount,iDate - 2,1)
    End If
	If iDate > 6 Then
      iUserLastWeek = aUserData(iCount,iDate - 7,1)
    End If
	If iDate > 29 Then
      iUserLastMonth = aUserData(iCount,iDate - 30,1)
    End If
	If Err <> 0 Then PutMess "Error calculating user history"
END SUB


'***************************************************************************************************
' SUB CalcUserHistory
' Calculate the user history
'***************************************************************************************************
SUB WriteTextReport
    DIM oFSO, oFile, sName, sUser, iCount
    DIM sDate, sYear, sMonth, sDay, sString
    sDate    = Date
    sYear    = Right(sDate, 4)
    sMonth   = Left(sDate,5)
    sMonth   = Right(sMonth,2)
    sDay     = Left(sDate,2)
 
    Set oFSO = CreateObject("Scripting.FileSystemObject")
    Set oFile = oFSO.OpenTextFile(REPORT_DIR & "\users.txt", 2, TRUE, 0)
    oFile.WriteLine("User; Path; Used MB; Yesterday MB; Week MB; Month MB")
	iCount = 0
	For Each sName In aUsers
      If sName <> "" and sName <> "0" and sName <> " " Then
        If iCount <= UBound(aUsers,1) Then
          CalcUserHistory(iCount)
          sSTring = ""
		  sString = aUsers(iCount,0) & "; " & aUsers(iCount,1) & "; "
		  sString = sString & FormatNumber((iUserToday / 1024) / 1024 , 3) & "; "
		  If iUserYesterDay = -1 Then
		    sString = sSTring & "not applicable; "
          Else
		    sString = sSTring & FormatNumber(((iUserToday - iUserYesterday) / 1024) / 1024 , 3) & "; "
          End If 
		  If iUserLastWeek = -1 Then
		    sString = sSTring & "not applicable; "
          Else
		    sString = sSTring & FormatNumber(((iUserToday - iUserLastWeek) / 1024) / 1024 , 3) & "; "
          End If 
		  If iUserLastMonth = -1 Then
		    sString = sSTring & "not applicable; "
          Else
		    sString = sSTring & FormatNumber(((iUserToday - iUserLastMonth) / 1024) / 1024 , 3) & "; "
          End If 
          oFile.WriteLine(sString) 
          iCount = iCount + 1
        End If
      End If
    Next 
    oFile.Close
    Set oFile = nothing
    Set oFSO  = nothing
END SUB
